@@ -3,7 +3,7 @@ package DateTime::Format::Natural::Duration;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.04';
 
 sub _pre_duration
 {
@@ -15,11 +15,16 @@ sub _pre_duration
     if ($duration->{for}->($date_strings)) {
         $self->{insert} = $self->parse_datetime('now');
     }
-    elsif ($duration->{first_last}->($date_strings)) {
+    elsif ($duration->{first_to_last}->($date_strings)) {
         if (my ($complete) = $date_strings->[1] =~ /^\S+? \s+ (.*)/x) {
             $date_strings->[0] .= " $complete";
         }
     }
+    elsif ($duration->{date_time_to_time}->($date_strings)) {
+        if (my ($complete) = $date_strings->[0] =~ /^(\S+?) \s+ .*/x) {
+            $date_strings->[1] = "$complete $date_strings->[1]";
+        }
+    }
 }
 
 sub _post_duration
@@ -37,7 +42,7 @@ sub _save_state
     my $self = shift;
     my %args = @_;
 
-    return if scalar keys %{$self->{state}};
+    return if %{$self->{state}};
 
     unless ($args{valid_expression}) {
         %{$self->{state}} = %args;
@@ -50,7 +55,7 @@ sub _restore_state
 
     my %state = %{$self->{state}};
 
-    if (scalar keys %state) {
+    if (%state) {
         $state{valid_expression}
           ? $self->_set_valid_exp
           : $self->_unset_valid_exp;
@@ -96,6 +101,6 @@ Steven Schubiger <schubiger@cpan.org>
 This program is free software; you may redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See L<http://www.perl.com/perl/misc/Artistic.html>
+See L<http://dev.perl.org/licenses/>
 
 =cut
